from django.contrib import admin

from admin_steroids.options import BetterRawIdFieldsModelAdmin
from admin_steroids.tests.models import Person


class PersonAdmin(BetterRawIdFieldsModelAdmin):

    list_display = ('name',)

    search_fields = ('name',)

    raw_id_fields = ('associates',)


admin.site.register(Person, PersonAdmin)



from django.db import models


class Person(models.Model):

    name = models.CharField(max_length=100, blank=False, null=False, unique=True)

    associates = models.ManyToManyField('self', blank=True)


class Contact(models.Model):

    person = models.ForeignKey(Person, on_delete=models.CASCADE)

    email = models.EmailField(max_length=100, blank=False, null=False)

    class Meta:
        unique_together = (('person', 'email'),)
